@@ -49,7 +49,7 @@ show_providers (ProviderConfigPrivate *priv)
 
 	/* create the data model */
 	model = gda_data_model_array_new (2);
-	gda_data_model_set_column_title (model, 0, _("Provider"));
+	gda_data_model_set_column_title (model, 0, _("Name"));
 	gda_data_model_set_column_title (model, 1, _("Description"));
 
 	prv_list = gda_config_get_provider_list ();
