@@ -20,12 +20,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <gtk/gtktable.h>
 #include <libgnomedb/gnome-db-dsn-config.h>
 #include <libgnomedb/gnome-db-provider-selector.h>
 #include <libgnomedb/gnome-db-util.h>
-#include <bonobo/bonobo-i18n.h>
+#include "gnome-db-i18n.h"
 
 #define PARENT_TYPE GTK_TYPE_VBOX
 
