@@ -23,12 +23,12 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
+#include <gtk/gtkwindow.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-login-dialog.h>
 #include <libgnomedb/gnome-db-stock.h>
 #include <libgnomedb/gnome-db-util.h>
-#include <libgnomeui/gnome-window-icon.h>
-#include <bonobo/bonobo-i18n.h>
+#include "gnome-db-i18n.h"
 
 struct _GnomeDbLoginDialogPrivate {
 	GtkWidget *login;
@@ -88,34 +88,47 @@ gnome_db_login_dialog_class_init (GnomeDbLoginDialogClass *klass)
 static void
 gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass *klass)
 {
-	GtkWidget *table, *image, *label;
+	GtkWidget *hbox, *vbox, *image, *label;
 
 	g_return_if_fail (GNOME_DB_IS_LOGIN_DIALOG (dialog));
 
 	dialog->priv = g_new0 (GnomeDbLoginDialogPrivate, 1);
-
+        
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GNOME_DB_STOCK_CONNECT, GTK_RESPONSE_OK);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
-	table = gnome_db_new_table_widget (2, 2, FALSE);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), table, TRUE, TRUE, 2);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
+        gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 12);
+        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+        gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
-	image = gtk_image_new_from_stock (GNOME_DB_STOCK_DATABASE, GTK_ICON_SIZE_DIALOG);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
+	gtk_widget_show (hbox);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 0);
+
+	/* image = gtk_image_new_from_stock (GNOME_DB_STOCK_DATABASE, GTK_ICON_SIZE_DIALOG); */
+	image = gtk_image_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db-database-login_48x48.png");
+        gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
 	gtk_widget_show (image);
-	gtk_table_attach (GTK_TABLE (table), image, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 5);
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
+	vbox = gtk_vbox_new (FALSE, 12);
+	gtk_widget_show (vbox);
+	
 	label = gnome_db_new_label_widget (_("Enter the arguments below to open a connection\n"
 					     "to a data source"));
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_CENTER);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0.5);
-	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 4, 4);
+	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+        gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
 
 	dialog->priv->login = gnome_db_login_new (NULL);
 	gtk_widget_show (dialog->priv->login);
-	gtk_table_attach (GTK_TABLE (table), dialog->priv->login, 1, 2, 1, 2,
-			  GTK_FILL | GTK_SHRINK | GTK_EXPAND,
-			  GTK_FILL | GTK_SHRINK | GTK_EXPAND, 2, 2);
+	gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->login, TRUE, TRUE, 0);
+	
+	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 }
 
 static void
@@ -209,12 +222,17 @@ gnome_db_login_dialog_get_type (void)
 GtkWidget *
 gnome_db_login_dialog_new (const gchar *title)
 {
+	GdkPixbuf *icon;
 	GnomeDbLoginDialog *dialog;
 
 	dialog = g_object_new (GNOME_DB_TYPE_LOGIN_DIALOG, NULL);
 	gtk_window_set_title (GTK_WINDOW (dialog), title);
-	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
-					 LIBGNOMEDB_ICONSDIR "/gnome-db.png");
+
+	icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
+	if (icon) {
+		gtk_window_set_icon (GTK_WINDOW (dialog), icon);
+		g_object_unref (icon);
+	}
 
 	return GTK_WIDGET (dialog);
 }
@@ -259,3 +277,18 @@ const gchar *gnome_db_login_dialog_get_password (GnomeDbLoginDialog *dialog)
 	g_return_val_if_fail (GNOME_DB_IS_LOGIN_DIALOG (dialog), NULL);
 	return gnome_db_login_get_password (GNOME_DB_LOGIN (dialog->priv->login));
 }
+
+/**
+ * gnome_db_login_dialog_get_login_widget
+ * @dialog: A #GnomeDbLoginDialog widget.
+ *
+ * Get the #GnomeDbLogin widget contained in a #GnomeDbLoginDialog.
+ *
+ * Returns: the login widget contained in the dialog.
+ */
+GtkWidget *
+gnome_db_login_dialog_get_login_widget (GnomeDbLoginDialog *dialog)
+{
+	g_return_val_if_fail (GNOME_DB_IS_LOGIN_DIALOG (dialog), NULL);
+	return dialog->priv->login;
+}
