@@ -20,13 +20,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <libgda/gda-config.h>
 #include <libgnomedb/gnome-db-data-source-selector.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-util.h>
 #include <gtk/gtktable.h>
-#include <bonobo/bonobo-i18n.h>
+#include <gtk/gtklabel.h>
+#include "gnome-db-i18n.h"
 
 struct _GnomeDbLoginPrivate {
 	gchar *dsn_name;
@@ -193,27 +193,35 @@ gnome_db_login_construct (GnomeDbLogin *login, const gchar *dsn)
 		login->priv->dsn_name = NULL;
 
 	table = gnome_db_new_table_widget (3, 2, FALSE);
+        gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+        gtk_table_set_col_spacings (GTK_TABLE (table), 6);
 	gtk_box_pack_start (GTK_BOX (login), table, TRUE, TRUE, 0);
 
-	label = gnome_db_new_label_widget (_("Data Source"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 2, 2);
+	label = gnome_db_new_label_widget (_("Data Source:"));
+        gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 	login->priv->dsn_entry = gnome_db_data_source_selector_new (dsn);
 	gtk_widget_show (login->priv->dsn_entry);
 	gtk_table_attach (GTK_TABLE (table), login->priv->dsn_entry, 1, 2, 0, 1,
-			  GTK_FILL, GTK_FILL, 2, 2);
+			  GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
 
-	label = gnome_db_new_label_widget (_("Username"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 2, 2);
+	label = gnome_db_new_label_widget (_("Username:"));
+        gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 	login->priv->username_entry = gnome_db_new_entry_widget (0, TRUE);
 	gtk_table_attach (GTK_TABLE (table), login->priv->username_entry, 1, 2, 1, 2,
-			  GTK_FILL, GTK_FILL, 2, 2);
+			  GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
 
-	label = gnome_db_new_label_widget (_("Password"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3, GTK_FILL, GTK_FILL, 2, 2);
+	label = gnome_db_new_label_widget (_("Password:"));
+        gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
 	login->priv->password_entry = gnome_db_new_entry_widget (0, TRUE);
 	gtk_entry_set_visibility (GTK_ENTRY (login->priv->password_entry), FALSE);
 	gtk_table_attach (GTK_TABLE (table), login->priv->password_entry, 1, 2, 2, 3,
-			  GTK_FILL, GTK_FILL, 2, 2);
+			  GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 0, 0);
 
 	return GTK_WIDGET (login);
 }
@@ -254,6 +262,20 @@ gnome_db_login_get_username (GnomeDbLogin *login)
 	return gtk_entry_get_text (GTK_ENTRY (login->priv->username_entry));
 }
 
+/**
+ * gnome_db_login_set_username
+ * @login: a #GnomeDbLogin widget.
+ * @username: username to display in the widget.
+ *
+ * Sets the user name to be displayed in the given #GnomeDbLogin widget.
+ */
+void
+gnome_db_login_set_username (GnomeDbLogin *login, const gchar *username)
+{
+	g_return_if_fail (GNOME_DB_IS_LOGIN (login));
+	gtk_entry_set_text (GTK_ENTRY (login->priv->username_entry), username);
+}
+
 /**
  * gnome_db_login_get_password
  */
@@ -263,3 +285,17 @@ gnome_db_login_get_password (GnomeDbLogin *login)
 	g_return_val_if_fail (GNOME_DB_IS_LOGIN (login), NULL);
 	return gtk_entry_get_text (GTK_ENTRY (login->priv->password_entry));
 }
+
+/**
+ * gnome_db_login_set_password
+ * @login: a #GnomeDbLogin widget.
+ * @password: password to display in the widget.
+ *
+ * Sets the password to be displayed in the given #GnomeDbLogin widget.
+ */
+void
+gnome_db_login_set_password (GnomeDbLogin *login, const gchar *password)
+{
+	g_return_if_fail (GNOME_DB_IS_LOGIN (login));
+	gtk_entry_set_text (GTK_ENTRY (login->priv->password_entry), password);
+}
